package fr.vincent.ramiere.mangerautourdesimplonback.models;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import jakarta.persistence.*;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * Entité représentant un utilisateur de l'application.
 */
@Entity
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class Personne implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Identifiant unique de la personne, généré automatiquement.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "id_personne")
    private int id;

    /**
     * Nom de famille de l'utilisateur.
     */
    @Column(nullable = false)
    private String nom;

    /**
     * Prénom de l'utilisateur.
     */
    @Column(nullable = false)
    private String prenom;

    /**
     * Adresse e-mail de l'utilisateur, utilisée comme identifiant de connexion.
     */
    @Column(nullable = false)
    private String email;

    /**
     * Mot de passe de l'utilisateur, stocké sous forme de hachage sécurisé.
     */
    @Column(nullable = false)
    private String password;

    /**
     * Collection des préférences (notes, favoris) de cet utilisateur pour les restaurants.
     * La suppression d'une personne entraîne la suppression de ses préférences.
     */
    @OneToMany(mappedBy = "preferencePK.personne", cascade = CascadeType.REMOVE)
    //@JsonIgnore
    @Builder.Default
    private Collection<Preference> preference = new ArrayList<>();

    /**
     * Liste des rôles attribués à l'utilisateur (ex: ROLE_ADMIN, ROLE_READER).
     * Chargée immédiatement avec l'entité (EAGER).
     */
    @ElementCollection(fetch = FetchType.EAGER)
    @Enumerated(EnumType.STRING)
    @Builder.Default
    private List<EnumRole> roleList = new ArrayList<>();

}
