package fr.vincent.ramiere.mangerautourdesimplonback.models;

import java.io.Serializable;

import jakarta.persistence.Column;
import jakarta.persistence.EmbeddedId;
import jakarta.persistence.Entity;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

/**
 * Entité représentant les préférences d'un utilisateur (Personne) pour un restaurant (Restaurant).
 * Utilise une clé primaire composite {@link PreferencePK}.
 */
@Entity
@Getter
@Setter
@NoArgsConstructor
@AllArgsConstructor
public class Preference implements Serializable {
    private static final long serialVersionUID = 1L;
    

    /**
     * Clé primaire composite, contenant les références vers Personne et Restaurant.
     */
    @EmbeddedId
    private PreferencePK preferencePK;

    /**
     * Note (de 1 à 5) attribuée par l'utilisateur au restaurant. Peut être nulle si non noté.
     */
	@Column // Par défaut, nullable = true pour Integer
	private Integer note;

    /**
     * Indique si le restaurant est marqué comme favori par l'utilisateur.
     */
	@Column(name = "favori")
	private Boolean favori;

    /**
     * Constructeur partiel pour initialiser avec la clé primaire.
     * Ce constructeur est conservé car @AllArgsConstructor ne couvre pas ce cas spécifique
     * si vous souhaitez initialiser uniquement avec la clé.
     * Si @AllArgsConstructor suffit, vous pouvez supprimer celui-ci.
     */
    public Preference(PreferencePK preferencePK){
        this.preferencePK = preferencePK;
    }
}