package fr.vincent.ramiere.mangerautourdesimplonback.models;

import com.fasterxml.jackson.annotation.JsonBackReference;
import jakarta.persistence.*;
import lombok.*;

import java.util.ArrayList;
import java.io.Serializable;
import java.util.List;

/**
 * Entité représentant un type de cuisine (ex: "Italien", "Japonais").
 */
@Entity
@Table(name = "type")
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class TypeRestau implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Identifiant unique du type de cuisine, généré automatiquement.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "id_type")
    private int id;

    /**
     * Nom du type de cuisine (ex: "Pizza", "Français").
     */
    @Column(nullable = false)
    private String libelle;

    /**
     * Liste des restaurants associés à ce type de cuisine.
     */
    @ManyToMany(mappedBy = "typerestaus")
    @JsonBackReference("restaurants")
    @Builder.Default
    private List<Restaurant> restaurants = new ArrayList<>();
}
